searchNodes=[{"doc":"Module defining the functionalities of Bincode.Bincode allows you to share data between Elixir and Rust using Rust's Bincode binary format.You can implement your custom serialization manually, but for most use cases you can simply declare the Rust structs and enums using Bincode.declare_struct/3 and Bincode.declare_enum/3Supported typesMost Rust types are supported, plus user defined structs and enums.RustBincode notationElixir typespecu8:u8non_neg_integer.........u128:u128non_neg_integeri8:i8integer.........i128:i128integerf32:f32floatf64:f64floatbool:boolbooleanString:stringbinary(u32, String){:u32, :string}{non_neg_integer, binary}Option&lt;f32&gt;{:option, :f32}float | nilVec&lt;String&gt;{:list, :string}[binary]HashMap&lt;i64, String&gt;{:map, {:i64, :string}}%{required(integer) =&gt; binary}HashSet&lt;u8&gt;{:set, :u8}MapSet.t(non_neg_integer)User defined types such as structs and enums can be nested, in this case the type is the fully qualified module name. See Bincode.declare_struct/3.The endianness is little since that's the default used by Bincode. Tuples are implemented for a max size of 12 by default. That should be enough for most practical cases but if you need to serialize tuples with more elements, you can set max_tuple_size in the mix config, like so:config :bincode, max_tuple_size: 23ExamplesConsider the typical example where we want to send data structures across the network. Here with a Rust client and Elixir server:#[derive(Serialize, Deserialize)] pub struct PacketSendMessage { pub from: u64, pub to: u64, pub content: String, } pub fn send_message(sender_id: u64, receiver_id: u64) { let message = PacketSendMessage { from: sender_id, to: receiver_id, content: &quot;hello!&quot;.to_owned() }; let encoded: Vec&lt;u8&gt; = bincode::serialize(&amp;message).unwrap(); // now send &quot;encoded&quot; to Elixir app }On the Elixir side you can simply declare the same packet struct and deserialize the received bytes:defmodule Packets do import Bincode declare_struct(PacketSendMessage, from: :u64, to: :u64, content: :string ) end alias Packets.PacketSendMessage # Receive &quot;data&quot; from the network {:ok, {%PacketSendMessage{} = message, rest}} = PacketSendMessage.deserialize(data) Logger.info(&quot;Received message packet \#{inspect(message)}&quot;)","ref":"Bincode.html","title":"Bincode","type":"module"},{"doc":"Declares a new enum. This macro generates a module for the enum, plus a struct for each variant with serialization and deserialization methods according to the given fields.Optionsabsolute - When set to true, the given struct name is interpreted as the absolute module name. When set to false, the given struct name is appended to the caller's module. Defaults to false.Exampledefmodule MyEnums do import Bincode declare_enum(IpAddr, V4: [tuple: {:u8, :u8, :u8, :u8}], V6: [addr: :string] ) end alias MyEnums.IpAddr ip_v4 = %IpAddr.V4{tuple: {127, 0, 0, 1}} {:ok, &lt;&lt;0, 0, 0, 0, 127, 0, 0, 1&gt;&gt;} = Bincode.serialize(ip_v4, IpAddr) ip_v6 = %IpAddr.V6{addr: &quot;::1&quot;} {:ok, &lt;&lt;1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 58, 58, 49&gt;&gt;} = Bincode.serialize(ip_v6, IpAddr)It's also possible to call serialize and deserialize from the struct module directly.{:ok, {%IpAddr.V4{tuple: {127, 0, 0, 1}}, &quot;&quot;}} = IpAddr.deserialize(&lt;&lt;0, 0, 0, 0, 127, 0, 0, 1&gt;&gt;) {:ok, {%IpAddr.V6{addr: &quot;::1&quot;}, &quot;&quot;}} = IpAddr.deserialize(&lt;&lt;1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 58, 58, 49&gt;&gt;)Enums can be nested and contain structs. See Bincode.declare_struct/3.","ref":"Bincode.html#declare_enum/3","title":"Bincode.declare_enum/3","type":"macro"},{"doc":"Declares a new struct. This macro generates a struct with serialization and deserialization methods according to the given fields.Optionsabsolute - When set to true, the given struct name is interpreted as the absolute module name. When set to false, the given struct name is appended to the caller's module. Defaults to false.Exampledefmodule MyStructs do import Bincode declare_struct(Person, first_name: :string, last_name: :string, age: :u8 ) end alias MyStructs.Person person = %Person{first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 44} {:ok, &lt;&lt;4, 0, 0, 0, 0, 0, 0, 0, 74, 111, 104, 110, 3, 0, 0, 0, 0, 0, 0, 0, 68, 111, 101, 44&gt;&gt;} = Bincode.serialize(person, Person)It's also possible to call serialize and deserialize from the struct module directly.{:ok, {%Person{age: 44, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;}, &quot;&quot;}} = Person.deserialize(&lt;&lt;4, 0, 0, 0, 0, 0, 0, 0, 74, 111, 104, 110, 3, 0, 0, 0, 0, 0, 0, 0, 68, 111, 101, 44&gt;&gt;)Structs and enums can be nested. In this case the type is the fully qualified module. For example:defmodule MyStructs do import Bincode declare_struct(Person, first_name: :string, last_name: :string, age: :u8 ) declare_struct(Employee, employee_number: :u64, person: MyStructs.Person, job_title: :string, ) end","ref":"Bincode.html#declare_struct/3","title":"Bincode.declare_struct/3","type":"macro"},{"doc":"Deserializes the given binary data into an Elixir term according to the given type.Returns {:ok, {term, rest}} when successful or {:error, error_message} otherwise. The remaining binary data is returned.Examplesiex&gt; Bincode.deserialize(&lt;&lt;255&gt;&gt;, :u8) {:ok, {255, &quot;&quot;}} iex&gt; Bincode.deserialize(&lt;&lt;7, 0, 0, 0, 0, 0, 0, 0, 66, 105, 110, 99, 111, 100, 101&gt;&gt;, :string) {:ok, {&quot;Bincode&quot;, &quot;&quot;}} iex&gt; Bincode.deserialize(&lt;&lt;144, 0, 0&gt;&gt;, {:u16, :bool}) {:ok, {{144, false}, &quot;&quot;}} iex&gt; Bincode.deserialize(&lt;&lt;4, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4&gt;&gt;, {:list, :u8}) {:ok, {[1, 2, 3, 4], &quot;&quot;}} iex&gt; Bincode.deserialize(&lt;&lt;1, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 115, 111, 109, 101, 32, 115, 116, 114, 105, 110, 103, 32, 107, 101, 121, 4, 171, 161, 22, 100, 0, 0, 0&gt;&gt;, {:map, {:string, :u64}}) {:ok, {%{&quot;some string key&quot; =&gt; 429876423428}, &quot;&quot;}} iex&gt; Bincode.deserialize([], :bool) {:error, &quot;Cannot deserialize value [] into type :bool&quot;}","ref":"Bincode.html#deserialize/2","title":"Bincode.deserialize/2","type":"function"},{"doc":"Same as deserialize/2 but raises an ArgumentError when the given value cannot be encoded according to type.Examplesiex&gt; Bincode.deserialize!(&lt;&lt;1, 54, 23&gt;&gt;, {:option, :u16}) {5942, &quot;&quot;} iex&gt; Bincode.deserialize!(&lt;&lt;&gt;&gt;, {:list, :string}) ** (ArgumentError) Cannot deserialize value &quot;&quot; into type :list","ref":"Bincode.html#deserialize!/2","title":"Bincode.deserialize!/2","type":"function"},{"doc":"Serializes the given term in binary representation according to the given type.Returns {:ok, serialized_term} when successful or {:error, error_message} otherwise.Examplesiex&gt; Bincode.serialize(255, :u8) {:ok, &lt;&lt;255&gt;&gt;} iex&gt; Bincode.serialize(&quot;Bincode&quot;, :string) {:ok, &lt;&lt;7, 0, 0, 0, 0, 0, 0, 0, 66, 105, 110, 99, 111, 100, 101&gt;&gt;} iex&gt; Bincode.serialize({144, false}, {:u16, :bool}) {:ok, &lt;&lt;144, 0, 0&gt;&gt;} iex&gt; Bincode.serialize([1, 2, 3, 4], {:list, :u8}) {:ok, &lt;&lt;4, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4&gt;&gt;} iex&gt; Bincode.serialize(%{&quot;some string key&quot; =&gt; 429876423428}, {:map, {:string, :u64}}) {:ok, &lt;&lt;1, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0, 115, 111, 109, 101, 32, 115, 116, 114, 105, 110, 103, 32, 107, 101, 121, 4, 171, 161, 22, 100, 0, 0, 0&gt;&gt;} iex&gt; Bincode.serialize(%{}, :bool) {:error, &quot;Cannot serialize value %{} into type :bool&quot;}","ref":"Bincode.html#serialize/2","title":"Bincode.serialize/2","type":"function"},{"doc":"Same as serialize/2 but raises an ArgumentError when the given value cannot be encoded according to type.Examplesiex&gt; Bincode.serialize!([111], {:list, :u16}) &lt;&lt;1, 0, 0, 0, 0, 0, 0, 0, 111, 0&gt;&gt; iex&gt; Bincode.serialize!(&lt;&lt;&gt;&gt;, {:option, :bool}) ** (ArgumentError) Cannot serialize value &quot;&quot; into type :bool","ref":"Bincode.html#serialize!/2","title":"Bincode.serialize!/2","type":"function"},{"doc":"","ref":"Bincode.html#t:bincode_type/0","title":"Bincode.bincode_type/0","type":"type"},{"doc":"","ref":"Bincode.html#t:collection/0","title":"Bincode.collection/0","type":"type"},{"doc":"","ref":"Bincode.html#t:floating_point/0","title":"Bincode.floating_point/0","type":"type"},{"doc":"","ref":"Bincode.html#t:primitive/0","title":"Bincode.primitive/0","type":"type"},{"doc":"","ref":"Bincode.html#t:signed/0","title":"Bincode.signed/0","type":"type"},{"doc":"","ref":"Bincode.html#t:unsigned/0","title":"Bincode.unsigned/0","type":"type"},{"doc":"","ref":"Bincode.html#t:user_defined/0","title":"Bincode.user_defined/0","type":"type"},{"doc":"Protocol responsible for serializing Elixir terms into binary representation. It is automatically implemented when you declare a struct with Bincode.declare_struct but you can also manually implement it for any Elixir term.","ref":"Bincode.Serializer.html","title":"Bincode.Serializer","type":"protocol"},{"doc":"Serialize the given term to a binary representation compatible with Rust's Bincode. Returns {:ok, serialized_term} or {:error, error_message}.","ref":"Bincode.Serializer.html#serialize/1","title":"Bincode.Serializer.serialize/1","type":"function"},{"doc":"","ref":"Bincode.Serializer.html#t:t/0","title":"Bincode.Serializer.t/0","type":"type"}]